==> mx-usb-unmounter_24.01.tar.xz: mx-usb-unmounter/translations/mx-usb-unmounter_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="27"/>
        <location filename="../mainwindow.cpp" line="213"/>
        <location filename="../mainwindow.cpp" line="362"/>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>MX USB Unmounter</source>
        <translation type="unfinished">MX Αποπροσάρτηση USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="54"/>
        <source>Double-Click to Unmount</source>
        <translation type="unfinished">Διπλό κλικ για αποπροσάρτηση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="146"/>
        <source>Volume</source>
        <translation type="unfinished">Τόμος</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="188"/>
        <source>No Removable Device</source>
        <translation type="unfinished">Δεν υπάρχει αφαιρούμενη συσκευή</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Unmounting </source>
        <translation type="unfinished">Αποπροσάρτηση </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>Other partitions still mounted on device</source>
        <translation type="unfinished">Παραμένουν και άλλες κατατμήσεις προσαρτημένες στη συσκευή</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>Unable to  Unmount, Device in Use</source>
        <translation type="unfinished">Δεν είναι δυνατή η  αποπροσάρτηση, Η συσκευή είναι σε χρήση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="329"/>
        <source>List Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <location filename="../mainwindow.cpp" line="379"/>
        <source>Enable Autostart?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>Unmount</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="379"/>
        <source>Autostart Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>About MX USB Unmounter</source>
        <translation type="unfinished">Περί του MX Αποπροσάρτηση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>Version: </source>
        <translation type="unfinished">Έκδοση: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Quickly Unmount Removable Media</source>
        <translation type="unfinished">Γρήγορη αποπροσάρτηση αφαιρούμενων μέσων</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished">Πνευματικά δικαιώματα (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation type="unfinished">Άδεια</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation type="unfinished">Άκυρο</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>usbunmounter</name>
    <message>
        <source>MX USB Unmounter</source>
        <translation type="vanished">MX Αποπροσάρτηση USB</translation>
    </message>
    <message>
        <source>Double-Click to Unmount</source>
        <translation type="vanished">Διπλό κλικ για αποπροσάρτηση</translation>
    </message>
    <message>
        <source>Volume</source>
        <translation type="vanished">Τόμος</translation>
    </message>
    <message>
        <source>No Removable Device</source>
        <translation type="vanished">Δεν υπάρχει αφαιρούμενη συσκευή</translation>
    </message>
    <message>
        <source>Unmounting </source>
        <translation type="vanished">Αποπροσάρτηση </translation>
    </message>
    <message>
        <source>Other partitions still mounted on device</source>
        <translation type="vanished">Παραμένουν και άλλες κατατμήσεις προσαρτημένες στη συσκευή</translation>
    </message>
    <message>
        <source>Unable to  Unmount, Device in Use</source>
        <translation type="vanished">Δεν είναι δυνατή η  αποπροσάρτηση, Η συσκευή είναι σε χρήση</translation>
    </message>
    <message>
        <source>About MX USB Unmounter</source>
        <translation type="vanished">Περί του MX Αποπροσάρτηση</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation type="vanished">Έκδοση: </translation>
    </message>
    <message>
        <source>Quickly Unmount Removable Media</source>
        <translation type="vanished">Γρήγορη αποπροσάρτηση αφαιρούμενων μέσων</translation>
    </message>
    <message>
        <source>Copyright (c) MX Linux</source>
        <translation type="vanished">Πνευματικά δικαιώματα (c) MX Linux</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Άκυρο</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Άδεια</translation>
    </message>
</context>
</TS>

==> mx-usb-unmounter_24.03.01.tar.xz: mx-usb-unmounter/translations/mx-usb-unmounter_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="27"/>
        <location filename="../mainwindow.cpp" line="213"/>
        <location filename="../mainwindow.cpp" line="362"/>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>MX USB Unmounter</source>
        <translation type="unfinished">MX Αποπροσάρτηση USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="54"/>
        <source>Double-Click to Unmount</source>
        <translation type="unfinished">Διπλό κλικ για αποπροσάρτηση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="146"/>
        <source>Volume</source>
        <translation type="unfinished">Τόμος</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="188"/>
        <source>No Removable Device</source>
        <translation type="unfinished">Δεν υπάρχει αφαιρούμενη συσκευή</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Unmounting </source>
        <translation type="unfinished">Αποπροσάρτηση </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>Other partitions still mounted on device</source>
        <translation type="unfinished">Παραμένουν και άλλες προσαρτημένες κατατμήσεις στη συσκευή</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>Unable to  Unmount, Device in Use</source>
        <translation type="unfinished">Δεν είναι δυνατή η  αποπροσάρτηση, Η συσκευή είναι σε χρήση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="329"/>
        <source>List Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <location filename="../mainwindow.cpp" line="379"/>
        <source>Enable Autostart?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>Unmount</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="379"/>
        <source>Autostart Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>About MX USB Unmounter</source>
        <translation type="unfinished">Περί του MX Αποπροσάρτηση USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>Version: </source>
        <translation type="unfinished">Έκδοση: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Quickly Unmount Removable Media</source>
        <translation type="unfinished">Γρήγορη αποπροσάρτηση αφαιρούμενων μέσων</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished">Πνευματικά δικαιώματα (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation type="unfinished">Άδεια</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation type="unfinished">Άκυρο</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>usbunmounter</name>
    <message>
        <source>MX USB Unmounter</source>
        <translation type="vanished">MX Αποπροσάρτηση USB</translation>
    </message>
    <message>
        <source>Double-Click to Unmount</source>
        <translation type="vanished">Διπλό κλικ για αποπροσάρτηση</translation>
    </message>
    <message>
        <source>Volume</source>
        <translation type="vanished">Τόμος</translation>
    </message>
    <message>
        <source>No Removable Device</source>
        <translation type="vanished">Δεν υπάρχει αφαιρούμενη συσκευή</translation>
    </message>
    <message>
        <source>Unmounting </source>
        <translation type="vanished">Αποπροσάρτηση </translation>
    </message>
    <message>
        <source>Other partitions still mounted on device</source>
        <translation type="vanished">Παραμένουν και άλλες προσαρτημένες κατατμήσεις στη συσκευή</translation>
    </message>
    <message>
        <source>Unable to  Unmount, Device in Use</source>
        <translation type="vanished">Δεν είναι δυνατή η  αποπροσάρτηση, Η συσκευή είναι σε χρήση</translation>
    </message>
    <message>
        <source>About MX USB Unmounter</source>
        <translation type="vanished">Περί του MX Αποπροσάρτηση USB</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation type="vanished">Έκδοση: </translation>
    </message>
    <message>
        <source>Quickly Unmount Removable Media</source>
        <translation type="vanished">Γρήγορη αποπροσάρτηση αφαιρούμενων μέσων</translation>
    </message>
    <message>
        <source>Copyright (c) MX Linux</source>
        <translation type="vanished">Πνευματικά δικαιώματα (c) MX Linux</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Άκυρο</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Άδεια</translation>
    </message>
</context>
</TS>
